==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ListPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelContentRefreshedEventArgsDescription } from "./ListPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelContentRefreshedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelContentRefreshedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
                ListPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelContentRefreshedEventArgsDescriptionMetadata.c(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ListPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ListPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
            a.ad("ListPanelContentRefreshedEventArgs", () => new ListPanelContentRefreshedEventArgsDescription());
            a.ac("ListPanelContentRefreshedEventArgs", ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelContentRefreshedEventArgsDescriptionMetadata.$t = markType(ListPanelContentRefreshedEventArgsDescriptionMetadata, 'ListPanelContentRefreshedEventArgsDescriptionMetadata');
    ListPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ListPanelContentRefreshedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ListPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelContentRefreshedEventArgsDescription } from "./ListPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelContentRefreshedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelContentRefreshedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
                ListPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelContentRefreshedEventArgsDescriptionMetadata.c(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ListPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ListPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
            a.ae("ListPanelContentRefreshedEventArgs", () => new ListPanelContentRefreshedEventArgsDescription());
            a.ad("ListPanelContentRefreshedEventArgs", ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelContentRefreshedEventArgsDescriptionMetadata.$t = markType(ListPanelContentRefreshedEventArgsDescriptionMetadata, 'ListPanelContentRefreshedEventArgsDescriptionMetadata');
    ListPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ListPanelContentRefreshedEventArgsDescriptionMetadata;
})();
